@@ -60,6 +60,7 @@ import com.openexchange.admin.plugins.OXContextPluginInterface;
 import com.openexchange.admin.tools.AdminCache;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.database.DatabaseService;
+import com.openexchange.database.migration.DBMigrationExecutorService;
 import com.openexchange.osgi.HousekeepingActivator;
 
 public class Activator extends HousekeepingActivator {
@@ -73,14 +74,14 @@ public class Activator extends HousekeepingActivator {
             ConfigurationService service = getService(ConfigurationService.class);
             AdminCache.compareAndSetConfigurationService(null, service);
             initCache(service);
-            track(DatabaseService.class, new DatabaseServiceCustomizer(context, ClientAdminThreadExtended.cache.getPool()));
+            track(DatabaseService.class, new DatabaseServiceCustomizer(context, ClientAdminThreadExtended.autocontextidCache.getPool()));
+            track(DBMigrationExecutorService.class, new AutoCIDDBMigrationServiceTracker(this, context));
             openTrackers();
 
             final Hashtable<String, String> props = new Hashtable<String, String>(2);
             props.put("name", "OXContext");
             LOG.info(OXContextPluginInterface.class.getName());
             registerService(OXContextPluginInterface.class, new OXAutoCIDContextImpl(), props);
-
         } catch (final SQLException e) {
             LOG.error("", e);
             throw e;
@@ -95,12 +96,12 @@ public class Activator extends HousekeepingActivator {
         cache.initCache(service);
         cache.initCacheExtended();
         cache.initIDGenerator();
-        ClientAdminThreadExtended.cache = cache;
+        ClientAdminThreadExtended.autocontextidCache = cache;
         LOG.info("AutocontextID Bundle: Cache and Pools initialized!");
     }
 
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { ConfigurationService.class, AdminDaemonService.class };
+        return new Class<?>[] { ConfigurationService.class, AdminDaemonService.class, DatabaseService.class, DBMigrationExecutorService.class };
     }
 }
